from django.contrib import admin
from django.utils.safestring import mark_safe
from django.utils.translation import ugettext_lazy as _

from django_pays import payment_url

from .models import Order, OrderPayment


@admin.register(Order)
class OrderAdmin(admin.ModelAdmin):
    list_display = ('name', 'order_id', 'amount', 'payment_link')

    def payment_link(self, obj):
        return mark_safe('<a href="{url}" target="_blank">{url}</a>'.format(
            url=payment_url(
                gateway=obj.pays_gateway,
                order_id=obj.order_id,
                amount=int(obj.amount * 100),
                currency='CZK',
            ),
        ))
    payment_link.short_description = _('payment link')
    payment_link.allow_tags = True


@admin.register(OrderPayment)
class OrderPaymentAdmin(admin.ModelAdmin):
    list_display = ('order', 'payment', 'amount')



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os

from setuptools import setup, find_packages

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    long_description = readme.read()

setup(
    name='django-pays',
    version='0.1.0',
    description='Django integration for Pays payment gateway.',
    long_description=long_description,
    author='Jakub Dorňák',
    author_email='jakub.dornak@misli.cz',
    license='BSD',
    url='https://github.com/misli/django-pays',
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 1.10',
        'Framework :: Django :: 1.11',
        'Framework :: Django :: 2.1',
        'Framework :: Django :: 2.2',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: Czech',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.6',
    ],
)



from django.db import models
from django.db.models.signals import post_save
from django.dispatch import receiver
from django.utils.translation import ugettext_lazy as _

from django_pays.models import Gateway, Payment


class Order(models.Model):
    name = models.CharField(max_length=30)
    order_id = models.CharField(max_length=10, unique=True)
    amount = models.DecimalField(_('amount'), decimal_places=2, max_digits=20)
    pays_gateway = models.ForeignKey(Gateway, on_delete=models.PROTECT)

    class Meta:
        verbose_name = _('order')
        verbose_name_plural = _('orders')

    def __str__(self):
        return self.name


class OrderPayment(models.Model):
    order = models.ForeignKey(Order, on_delete=models.CASCADE)
    payment = models.OneToOneField(Payment, editable=False, null=True, on_delete=models.CASCADE,
                                   related_name='identified_order_payment')
    amount = models.DecimalField(_('amount'), decimal_places=2, max_digits=20)

    class Meta:
        verbose_name = _('order payment')
        verbose_name_plural = _('order payments')

    def __str__(self):
        return '{}, {}'.format(self.order, self.amount)


@receiver(post_save, sender=Payment)
def create_order_payment(instance, **kwargs):
    payment = instance
    if payment.status == Payment.REALIZED:
        order = Order.objects.filter(order_id=payment.order_id).first()
        if order:
            OrderPayment.objects.create(order=order, payment=payment, amount=payment.amount / payment.base_units)
